# Form implementation generated from reading ui file 'src/eric7/QScintilla/ReplaceWidget.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_ReplaceWidget(object):
    def setupUi(self, ReplaceWidget):
        ReplaceWidget.setObjectName("ReplaceWidget")
        ReplaceWidget.resize(813, 54)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(ReplaceWidget.sizePolicy().hasHeightForWidth())
        ReplaceWidget.setSizePolicy(sizePolicy)
        self.gridLayout = QtWidgets.QGridLayout(ReplaceWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.closeButton = QtWidgets.QToolButton(ReplaceWidget)
        self.closeButton.setText("")
        self.closeButton.setObjectName("closeButton")
        self.gridLayout.addWidget(self.closeButton, 0, 0, 1, 1)
        self.label = QtWidgets.QLabel(ReplaceWidget)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 1, 1, 1)
        self.findtextCombo = QtWidgets.QComboBox(ReplaceWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.findtextCombo.sizePolicy().hasHeightForWidth())
        self.findtextCombo.setSizePolicy(sizePolicy)
        self.findtextCombo.setMinimumSize(QtCore.QSize(300, 0))
        self.findtextCombo.setEditable(True)
        self.findtextCombo.setInsertPolicy(QtWidgets.QComboBox.InsertPolicy.InsertAtTop)
        self.findtextCombo.setDuplicatesEnabled(False)
        self.findtextCombo.setObjectName("findtextCombo")
        self.gridLayout.addWidget(self.findtextCombo, 0, 2, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.findPrevButton = QtWidgets.QToolButton(ReplaceWidget)
        self.findPrevButton.setObjectName("findPrevButton")
        self.horizontalLayout.addWidget(self.findPrevButton)
        self.findNextButton = QtWidgets.QToolButton(ReplaceWidget)
        self.findNextButton.setObjectName("findNextButton")
        self.horizontalLayout.addWidget(self.findNextButton)
        self.extendButton = QtWidgets.QToolButton(ReplaceWidget)
        self.extendButton.setObjectName("extendButton")
        self.horizontalLayout.addWidget(self.extendButton)
        self.gridLayout.addLayout(self.horizontalLayout, 0, 3, 1, 1)
        self.caseCheckBox = QtWidgets.QCheckBox(ReplaceWidget)
        self.caseCheckBox.setObjectName("caseCheckBox")
        self.gridLayout.addWidget(self.caseCheckBox, 0, 4, 1, 1)
        self.wordCheckBox = QtWidgets.QCheckBox(ReplaceWidget)
        self.wordCheckBox.setObjectName("wordCheckBox")
        self.gridLayout.addWidget(self.wordCheckBox, 0, 5, 1, 1)
        self.regexpCheckBox = QtWidgets.QCheckBox(ReplaceWidget)
        self.regexpCheckBox.setObjectName("regexpCheckBox")
        self.gridLayout.addWidget(self.regexpCheckBox, 0, 6, 1, 1)
        self.label_2 = QtWidgets.QLabel(ReplaceWidget)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 1, 1, 1)
        self.replacetextCombo = QtWidgets.QComboBox(ReplaceWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.replacetextCombo.sizePolicy().hasHeightForWidth())
        self.replacetextCombo.setSizePolicy(sizePolicy)
        self.replacetextCombo.setMinimumSize(QtCore.QSize(300, 0))
        self.replacetextCombo.setEditable(True)
        self.replacetextCombo.setInsertPolicy(QtWidgets.QComboBox.InsertPolicy.InsertAtTop)
        self.replacetextCombo.setDuplicatesEnabled(False)
        self.replacetextCombo.setObjectName("replacetextCombo")
        self.gridLayout.addWidget(self.replacetextCombo, 1, 2, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.replaceButton = QtWidgets.QToolButton(ReplaceWidget)
        self.replaceButton.setObjectName("replaceButton")
        self.horizontalLayout_2.addWidget(self.replaceButton)
        self.replaceSearchButton = QtWidgets.QToolButton(ReplaceWidget)
        self.replaceSearchButton.setObjectName("replaceSearchButton")
        self.horizontalLayout_2.addWidget(self.replaceSearchButton)
        self.replaceAllButton = QtWidgets.QToolButton(ReplaceWidget)
        self.replaceAllButton.setObjectName("replaceAllButton")
        self.horizontalLayout_2.addWidget(self.replaceAllButton)
        self.gridLayout.addLayout(self.horizontalLayout_2, 1, 3, 1, 1)
        self.wrapCheckBox = QtWidgets.QCheckBox(ReplaceWidget)
        self.wrapCheckBox.setObjectName("wrapCheckBox")
        self.gridLayout.addWidget(self.wrapCheckBox, 1, 4, 1, 1)
        self.selectionCheckBox = QtWidgets.QCheckBox(ReplaceWidget)
        self.selectionCheckBox.setObjectName("selectionCheckBox")
        self.gridLayout.addWidget(self.selectionCheckBox, 1, 5, 1, 1)
        self.label.setBuddy(self.findtextCombo)
        self.label_2.setBuddy(self.replacetextCombo)

        self.retranslateUi(ReplaceWidget)
        QtCore.QMetaObject.connectSlotsByName(ReplaceWidget)
        ReplaceWidget.setTabOrder(self.findtextCombo, self.replacetextCombo)
        ReplaceWidget.setTabOrder(self.replacetextCombo, self.caseCheckBox)
        ReplaceWidget.setTabOrder(self.caseCheckBox, self.wordCheckBox)
        ReplaceWidget.setTabOrder(self.wordCheckBox, self.regexpCheckBox)
        ReplaceWidget.setTabOrder(self.regexpCheckBox, self.wrapCheckBox)
        ReplaceWidget.setTabOrder(self.wrapCheckBox, self.selectionCheckBox)
        ReplaceWidget.setTabOrder(self.selectionCheckBox, self.extendButton)
        ReplaceWidget.setTabOrder(self.extendButton, self.findNextButton)
        ReplaceWidget.setTabOrder(self.findNextButton, self.findPrevButton)
        ReplaceWidget.setTabOrder(self.findPrevButton, self.replaceSearchButton)
        ReplaceWidget.setTabOrder(self.replaceSearchButton, self.replaceAllButton)
        ReplaceWidget.setTabOrder(self.replaceAllButton, self.replaceButton)
        ReplaceWidget.setTabOrder(self.replaceButton, self.closeButton)

    def retranslateUi(self, ReplaceWidget):
        _translate = QtCore.QCoreApplication.translate
        ReplaceWidget.setWindowTitle(_translate("ReplaceWidget", "Find and Replace"))
        self.closeButton.setToolTip(_translate("ReplaceWidget", "Press to close the window"))
        self.label.setText(_translate("ReplaceWidget", "&Find:"))
        self.findPrevButton.setToolTip(_translate("ReplaceWidget", "Press to find the previous occurrence"))
        self.findNextButton.setToolTip(_translate("ReplaceWidget", "Press to find the next occurrence"))
        self.extendButton.setToolTip(_translate("ReplaceWidget", "Press to extend the search to the whole word"))
        self.caseCheckBox.setText(_translate("ReplaceWidget", "&Match case"))
        self.wordCheckBox.setText(_translate("ReplaceWidget", "Whole &word"))
        self.regexpCheckBox.setText(_translate("ReplaceWidget", "Rege&xp"))
        self.label_2.setText(_translate("ReplaceWidget", "&Replace:"))
        self.replaceButton.setToolTip(_translate("ReplaceWidget", "Press to replace the selection"))
        self.replaceSearchButton.setToolTip(_translate("ReplaceWidget", "Press to replace the selection and search for the next occurence"))
        self.replaceAllButton.setToolTip(_translate("ReplaceWidget", "Press to replace all occurrences"))
        self.wrapCheckBox.setText(_translate("ReplaceWidget", "Wrap &around"))
        self.selectionCheckBox.setText(_translate("ReplaceWidget", "&Selection only"))
