# Form implementation generated from reading ui file 'src/eric7/CodeFormatting/FormattingDiffWidget.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_FormattingDiffWidget(object):
    def setupUi(self, FormattingDiffWidget):
        FormattingDiffWidget.setObjectName("FormattingDiffWidget")
        FormattingDiffWidget.resize(700, 700)
        self.verticalLayout = QtWidgets.QVBoxLayout(FormattingDiffWidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.diffEdit = QtWidgets.QPlainTextEdit(FormattingDiffWidget)
        self.diffEdit.setLineWrapMode(QtWidgets.QPlainTextEdit.LineWrapMode.NoWrap)
        self.diffEdit.setReadOnly(True)
        self.diffEdit.setTabStopDistance(8.0)
        self.diffEdit.setObjectName("diffEdit")
        self.verticalLayout.addWidget(self.diffEdit)
        self.buttonBox = QtWidgets.QDialogButtonBox(FormattingDiffWidget)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(FormattingDiffWidget)
        self.buttonBox.rejected.connect(FormattingDiffWidget.close) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(FormattingDiffWidget)

    def retranslateUi(self, FormattingDiffWidget):
        _translate = QtCore.QCoreApplication.translate
        FormattingDiffWidget.setWindowTitle(_translate("FormattingDiffWidget", "Reformatting Differences"))
