# Form implementation generated from reading ui file 'src/eric7/DataViews/PyCoverageJsonReportDialog.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_PyCoverageJsonReportDialog(object):
    def setupUi(self, PyCoverageJsonReportDialog):
        PyCoverageJsonReportDialog.setObjectName("PyCoverageJsonReportDialog")
        PyCoverageJsonReportDialog.resize(500, 98)
        PyCoverageJsonReportDialog.setSizeGripEnabled(True)
        self.gridLayout = QtWidgets.QGridLayout(PyCoverageJsonReportDialog)
        self.gridLayout.setObjectName("gridLayout")
        self.compactCheckBox = QtWidgets.QCheckBox(PyCoverageJsonReportDialog)
        self.compactCheckBox.setChecked(True)
        self.compactCheckBox.setObjectName("compactCheckBox")
        self.gridLayout.addWidget(self.compactCheckBox, 1, 0, 1, 2)
        self.label_2 = QtWidgets.QLabel(PyCoverageJsonReportDialog)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 0, 0, 1, 1)
        self.outputFilePicker = EricPathPicker(PyCoverageJsonReportDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.outputFilePicker.sizePolicy().hasHeightForWidth())
        self.outputFilePicker.setSizePolicy(sizePolicy)
        self.outputFilePicker.setFocusPolicy(QtCore.Qt.FocusPolicy.StrongFocus)
        self.outputFilePicker.setObjectName("outputFilePicker")
        self.gridLayout.addWidget(self.outputFilePicker, 0, 1, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(PyCoverageJsonReportDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 2, 0, 1, 2)

        self.retranslateUi(PyCoverageJsonReportDialog)
        self.buttonBox.accepted.connect(PyCoverageJsonReportDialog.accept) # type: ignore
        self.buttonBox.rejected.connect(PyCoverageJsonReportDialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(PyCoverageJsonReportDialog)

    def retranslateUi(self, PyCoverageJsonReportDialog):
        _translate = QtCore.QCoreApplication.translate
        PyCoverageJsonReportDialog.setWindowTitle(_translate("PyCoverageJsonReportDialog", "JSON Report"))
        self.compactCheckBox.setToolTip(_translate("PyCoverageJsonReportDialog", "Select to create the report using the compact format"))
        self.compactCheckBox.setText(_translate("PyCoverageJsonReportDialog", "Compact Format"))
        self.label_2.setText(_translate("PyCoverageJsonReportDialog", "Output File:"))
        self.outputFilePicker.setToolTip(_translate("PyCoverageJsonReportDialog", "Enter the path of the output file"))
from eric7.EricWidgets.EricPathPicker import EricPathPicker
