# Form implementation generated from reading ui file 'src/eric7/CycloneDXInterface/CycloneDXMetaDataDialog.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_CycloneDXMetaDataDialog(object):
    def setupUi(self, CycloneDXMetaDataDialog):
        CycloneDXMetaDataDialog.setObjectName("CycloneDXMetaDataDialog")
        CycloneDXMetaDataDialog.resize(600, 600)
        CycloneDXMetaDataDialog.setSizeGripEnabled(True)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(CycloneDXMetaDataDialog)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupBox = QtWidgets.QGroupBox(CycloneDXMetaDataDialog)
        self.groupBox.setObjectName("groupBox")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout.setObjectName("formLayout")
        self.nameLabel = QtWidgets.QLabel(self.groupBox)
        self.nameLabel.setObjectName("nameLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.nameLabel)
        self.nameEdit = QtWidgets.QLineEdit(self.groupBox)
        self.nameEdit.setClearButtonEnabled(True)
        self.nameEdit.setObjectName("nameEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.nameEdit)
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label)
        self.typeComboBox = QtWidgets.QComboBox(self.groupBox)
        self.typeComboBox.setObjectName("typeComboBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.typeComboBox)
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_2)
        self.versionEdit = QtWidgets.QLineEdit(self.groupBox)
        self.versionEdit.setClearButtonEnabled(True)
        self.versionEdit.setObjectName("versionEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.versionEdit)
        self.descriptionLabel = QtWidgets.QLabel(self.groupBox)
        self.descriptionLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignTop)
        self.descriptionLabel.setObjectName("descriptionLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.ItemRole.LabelRole, self.descriptionLabel)
        self.descriptionEdit = EricSpellCheckedTextEdit(self.groupBox)
        self.descriptionEdit.setTabChangesFocus(True)
        self.descriptionEdit.setAcceptRichText(False)
        self.descriptionEdit.setObjectName("descriptionEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.ItemRole.FieldRole, self.descriptionEdit)
        self.verticalLayout_2.addWidget(self.groupBox)
        self.groupBox_2 = QtWidgets.QGroupBox(CycloneDXMetaDataDialog)
        self.groupBox_2.setObjectName("groupBox_2")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupBox_2)
        self.formLayout_2.setObjectName("formLayout_2")
        self.authorLabel = QtWidgets.QLabel(self.groupBox_2)
        self.authorLabel.setObjectName("authorLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.authorLabel)
        self.authorEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.authorEdit.setClearButtonEnabled(True)
        self.authorEdit.setObjectName("authorEdit")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.authorEdit)
        self.emailLabel = QtWidgets.QLabel(self.groupBox_2)
        self.emailLabel.setObjectName("emailLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.emailLabel)
        self.emailEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.emailEdit.setClearButtonEnabled(True)
        self.emailEdit.setObjectName("emailEdit")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.emailEdit)
        self.verticalLayout_2.addWidget(self.groupBox_2)
        self.groupBox_3 = QtWidgets.QGroupBox(CycloneDXMetaDataDialog)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout.setObjectName("verticalLayout")
        self.licenseComboBox = QtWidgets.QComboBox(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.licenseComboBox.sizePolicy().hasHeightForWidth())
        self.licenseComboBox.setSizePolicy(sizePolicy)
        self.licenseComboBox.setEditable(True)
        self.licenseComboBox.setObjectName("licenseComboBox")
        self.verticalLayout.addWidget(self.licenseComboBox)
        self.verticalLayout_2.addWidget(self.groupBox_3)
        self.groupBox_4 = QtWidgets.QGroupBox(CycloneDXMetaDataDialog)
        self.groupBox_4.setObjectName("groupBox_4")
        self.formLayout_3 = QtWidgets.QFormLayout(self.groupBox_4)
        self.formLayout_3.setObjectName("formLayout_3")
        self.label_3 = QtWidgets.QLabel(self.groupBox_4)
        self.label_3.setObjectName("label_3")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_3)
        self.manufacturerEdit = QtWidgets.QLineEdit(self.groupBox_4)
        self.manufacturerEdit.setClearButtonEnabled(True)
        self.manufacturerEdit.setObjectName("manufacturerEdit")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.manufacturerEdit)
        self.label_4 = QtWidgets.QLabel(self.groupBox_4)
        self.label_4.setObjectName("label_4")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_4)
        self.supplierEdit = QtWidgets.QLineEdit(self.groupBox_4)
        self.supplierEdit.setClearButtonEnabled(True)
        self.supplierEdit.setObjectName("supplierEdit")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.supplierEdit)
        self.verticalLayout_2.addWidget(self.groupBox_4)
        self.buttonBox = QtWidgets.QDialogButtonBox(CycloneDXMetaDataDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout_2.addWidget(self.buttonBox)
        self.nameLabel.setBuddy(self.nameEdit)
        self.descriptionLabel.setBuddy(self.descriptionEdit)
        self.authorLabel.setBuddy(self.authorEdit)
        self.emailLabel.setBuddy(self.emailEdit)

        self.retranslateUi(CycloneDXMetaDataDialog)
        self.buttonBox.accepted.connect(CycloneDXMetaDataDialog.accept) # type: ignore
        self.buttonBox.rejected.connect(CycloneDXMetaDataDialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(CycloneDXMetaDataDialog)
        CycloneDXMetaDataDialog.setTabOrder(self.nameEdit, self.typeComboBox)
        CycloneDXMetaDataDialog.setTabOrder(self.typeComboBox, self.versionEdit)
        CycloneDXMetaDataDialog.setTabOrder(self.versionEdit, self.descriptionEdit)
        CycloneDXMetaDataDialog.setTabOrder(self.descriptionEdit, self.authorEdit)
        CycloneDXMetaDataDialog.setTabOrder(self.authorEdit, self.emailEdit)
        CycloneDXMetaDataDialog.setTabOrder(self.emailEdit, self.licenseComboBox)
        CycloneDXMetaDataDialog.setTabOrder(self.licenseComboBox, self.manufacturerEdit)
        CycloneDXMetaDataDialog.setTabOrder(self.manufacturerEdit, self.supplierEdit)

    def retranslateUi(self, CycloneDXMetaDataDialog):
        _translate = QtCore.QCoreApplication.translate
        CycloneDXMetaDataDialog.setWindowTitle(_translate("CycloneDXMetaDataDialog", "SBOM Meta Data"))
        self.groupBox.setTitle(_translate("CycloneDXMetaDataDialog", "Component"))
        self.nameLabel.setText(_translate("CycloneDXMetaDataDialog", "Name:"))
        self.nameEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter the component name"))
        self.label.setText(_translate("CycloneDXMetaDataDialog", "Type:"))
        self.typeComboBox.setToolTip(_translate("CycloneDXMetaDataDialog", "Select the component type"))
        self.label_2.setText(_translate("CycloneDXMetaDataDialog", "Version:"))
        self.versionEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter the version number"))
        self.descriptionLabel.setText(_translate("CycloneDXMetaDataDialog", "Description:"))
        self.descriptionEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter a description of the component"))
        self.groupBox_2.setTitle(_translate("CycloneDXMetaDataDialog", "Author"))
        self.authorLabel.setText(_translate("CycloneDXMetaDataDialog", "Name:"))
        self.authorEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter author\'s name"))
        self.emailLabel.setText(_translate("CycloneDXMetaDataDialog", "Email:"))
        self.emailEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter author\'s email"))
        self.groupBox_3.setTitle(_translate("CycloneDXMetaDataDialog", "License"))
        self.licenseComboBox.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter or select the license"))
        self.groupBox_4.setTitle(_translate("CycloneDXMetaDataDialog", "Various"))
        self.label_3.setText(_translate("CycloneDXMetaDataDialog", "Manufacturer:"))
        self.manufacturerEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter the name of the manufacturer"))
        self.label_4.setText(_translate("CycloneDXMetaDataDialog", "Supplier:"))
        self.supplierEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter the name of the supplier"))
from eric7.EricWidgets.EricSpellCheckedTextEdit import EricSpellCheckedTextEdit
