# Form implementation generated from reading ui file 'src/eric7/CodeFormatting/IsortFormattingDialog.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_IsortFormattingDialog(object):
    def setupUi(self, IsortFormattingDialog):
        IsortFormattingDialog.setObjectName("IsortFormattingDialog")
        IsortFormattingDialog.resize(700, 650)
        IsortFormattingDialog.setSizeGripEnabled(True)
        self.verticalLayout = QtWidgets.QVBoxLayout(IsortFormattingDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.label_2 = QtWidgets.QLabel(IsortFormattingDialog)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.statusFilterComboBox = QtWidgets.QComboBox(IsortFormattingDialog)
        self.statusFilterComboBox.setMinimumSize(QtCore.QSize(150, 0))
        self.statusFilterComboBox.setSizeAdjustPolicy(QtWidgets.QComboBox.SizeAdjustPolicy.AdjustToMinimumContentsLengthWithIcon)
        self.statusFilterComboBox.setObjectName("statusFilterComboBox")
        self.horizontalLayout.addWidget(self.statusFilterComboBox)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.resultsList = QtWidgets.QTreeWidget(IsortFormattingDialog)
        self.resultsList.setAlternatingRowColors(True)
        self.resultsList.setRootIsDecorated(False)
        self.resultsList.setItemsExpandable(False)
        self.resultsList.setObjectName("resultsList")
        self.verticalLayout.addWidget(self.resultsList)
        self.statisticsGroup = QtWidgets.QGroupBox(IsortFormattingDialog)
        self.statisticsGroup.setObjectName("statisticsGroup")
        self.gridLayout = QtWidgets.QGridLayout(self.statisticsGroup)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(self.statisticsGroup)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.totalCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.totalCountLabel.setText("0")
        self.totalCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.totalCountLabel.setObjectName("totalCountLabel")
        self.gridLayout.addWidget(self.totalCountLabel, 0, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(183, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem1, 0, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.statisticsGroup)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 0, 3, 1, 1)
        self.skippedCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.skippedCountLabel.setText("0")
        self.skippedCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.skippedCountLabel.setObjectName("skippedCountLabel")
        self.gridLayout.addWidget(self.skippedCountLabel, 0, 4, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(182, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem2, 0, 5, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.statisticsGroup)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 0, 6, 1, 1)
        self.failuresCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.failuresCountLabel.setText("0")
        self.failuresCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.failuresCountLabel.setObjectName("failuresCountLabel")
        self.gridLayout.addWidget(self.failuresCountLabel, 0, 7, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.statisticsGroup)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 1, 0, 1, 1)
        self.processedCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.processedCountLabel.setText("0")
        self.processedCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.processedCountLabel.setObjectName("processedCountLabel")
        self.gridLayout.addWidget(self.processedCountLabel, 1, 1, 1, 1)
        self.reformattedLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.reformattedLabel.setObjectName("reformattedLabel")
        self.gridLayout.addWidget(self.reformattedLabel, 1, 3, 1, 1)
        self.reformattedCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.reformattedCountLabel.setText("0")
        self.reformattedCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.reformattedCountLabel.setObjectName("reformattedCountLabel")
        self.gridLayout.addWidget(self.reformattedCountLabel, 1, 4, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.statisticsGroup)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 1, 6, 1, 1)
        self.unchangedCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.unchangedCountLabel.setText("0")
        self.unchangedCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.unchangedCountLabel.setObjectName("unchangedCountLabel")
        self.gridLayout.addWidget(self.unchangedCountLabel, 1, 7, 1, 1)
        self.verticalLayout.addWidget(self.statisticsGroup)
        self.progressBar = QtWidgets.QProgressBar(IsortFormattingDialog)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout.addWidget(self.progressBar)
        self.buttonBox = QtWidgets.QDialogButtonBox(IsortFormattingDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(IsortFormattingDialog)
        QtCore.QMetaObject.connectSlotsByName(IsortFormattingDialog)
        IsortFormattingDialog.setTabOrder(self.resultsList, self.statusFilterComboBox)

    def retranslateUi(self, IsortFormattingDialog):
        _translate = QtCore.QCoreApplication.translate
        IsortFormattingDialog.setWindowTitle(_translate("IsortFormattingDialog", "Sort Imports with isort"))
        self.label_2.setText(_translate("IsortFormattingDialog", "Status Filter:"))
        self.statusFilterComboBox.setToolTip(_translate("IsortFormattingDialog", "Select the status of items to be shown (empty for all)."))
        self.resultsList.setSortingEnabled(True)
        self.resultsList.headerItem().setText(0, _translate("IsortFormattingDialog", "Status"))
        self.resultsList.headerItem().setText(1, _translate("IsortFormattingDialog", "File Name"))
        self.statisticsGroup.setTitle(_translate("IsortFormattingDialog", "Statistics"))
        self.label.setText(_translate("IsortFormattingDialog", "Total Files:"))
        self.label_3.setText(_translate("IsortFormattingDialog", "Skipped:"))
        self.label_5.setText(_translate("IsortFormattingDialog", "Failures:"))
        self.label_6.setText(_translate("IsortFormattingDialog", "Processed:"))
        self.reformattedLabel.setText(_translate("IsortFormattingDialog", "Resorted:"))
        self.label_4.setText(_translate("IsortFormattingDialog", "Unchanged:"))
        self.progressBar.setFormat(_translate("IsortFormattingDialog", "%v/%m Files"))
